==> 0.0.1.tar.gz: ios/Classes/Splash/YFAdsSplashManager.m <==
//
//  Splash.m
//  WanhuiDemo
//
//  Created by denglongmin on 2020/8/7.
//  Copyright © 2020 denglongmin. All rights reserved.
//

#import "YFAdsSplashManager.h"
#import <UIKit/UIKit.h>
#import "YFAdsConstant.h"
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdSplash.h>

@interface YFAdsSplashManager()<YFAdSplashDelegate>

@property (nonatomic, strong) YFAdSplash *splashAd;
@property (nonatomic, copy) NSString *posId;
@property (nonatomic) NSTimeInterval lastRequestTime;
@property (nonatomic, strong) FlutterEventSink flutterEventSink;

@end

@implementation YFAdsSplashManager

- (instancetype)initWithPostId:(NSString *)posId eventSink:(FlutterEventSink)eventSink {
    self = [super init];
    self.posId = posId;
    self.flutterEventSink = eventSink;
    return self;
}

//设置进入后台的时间戳
- (void)setAppBackTimeStamp {
    self.lastRequestTime = [NSDate date].timeIntervalSince1970;
}

- (void)hotLoadAdAndShow {
    if (([NSDate date].timeIntervalSince1970 - self.lastRequestTime) < 10) {
        NSLog(@"冷却时间小于10秒钟");
        return;
    }
    [self loadSplash];

}

- (void)loadAdAndShow {
    [self loadSplash];
}

- (UIView *)buildBgView {
    UIView *bgView = [[UIView alloc] initWithFrame:[UIScreen mainScreen].bounds];
    bgView.backgroundColor = [UIColor whiteColor];

    NSString *path = [[NSBundle mainBundle] pathForResource:@"default_splash_back" ofType:@"png"];
    BOOL fileExists = [[NSFileManager defaultManager] fileExistsAtPath:path];
    if(fileExists){
        UIImage *imgBg = [UIImage imageNamed:@"default_splash_back.png"];
        CGFloat imgHeight = imgBg.size.height/imgBg.size.width*kScreenWidth;
        UIImageView* bgImgView = [[UIImageView alloc] initWithFrame:CGRectMake(0, kScreenHeight-imgHeight, kScreenWidth, imgHeight)];
        bgImgView.image = imgBg;
        [bgView addSubview:bgImgView];
    }
    return bgView;
}

 
- (YFAdSplash *)returnAdInstance {
    YFAdSplash *splash = [[YFAdSplash alloc] initWithAdUnitID:self.posId viewController:nil];
    splash.delegate = self;
    splash.showLogoRequire = YES;
    splash.logoImage = [UIImage imageNamed:@"app_logo"];
    splash.backgroundImage = [UIImage imageNamed:@"LaunchImage_img"];
    splash.timeout = 5;
    return splash;
}


#pragma mark YFAdSplashDelegate


- (void)loadSplash{

    self.splashAd = [self returnAdInstance];
    [self.splashAd loadAndShowAd];
    
}

- (void)dealloc {
    self.splashAd = nil;
    self.splashAd.delegate = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据加载成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];

}
/// 广告曝光成功
- (void)fcAdExposured {
    NSLog(@"广告曝光成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdExpose" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告数据加载失败 %s %@", __func__,description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdLoadFail" forKey:KEY_METHOD];
    [result setValue:error.localizedDescription forKey:KEY_ERROR];
    [self callBack:result];
}

/// 广告点击
- (void)fcAdClicked {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidClick" forKey:KEY_METHOD];
    [self callBack:result];
    
}

/// 广告关闭
- (void)fcAdDidClose {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];

}

/// 广告倒计时结束
- (void)fcAdSplashOnAdCountdownToZero {
    NSLog(@"广告倒计时结束 %s", __func__);
}

/// 点击了跳过
- (void)fcAdSplashOnAdSkipClicked {
    NSLog(@"点击了跳过 %s", __func__);
}

///// 开屏广告即将关闭
//- (void)WHSplashAdCustomWillClosed:(WHSplashAd *)splashAd {
//    NSLog(@"WH开屏自定义广告即将关闭");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHSplashAdCustomWillClosed" forKey:KEY_METHOD];
//    [self callBack:result];
//}


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_SPLASH forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}


@end

==> 0.0.2.tar.gz: ios/Classes/Splash/YFAdsSplashManager.m <==
//
//  Splash.m
//  WanhuiDemo
//
//  Created by denglongmin on 2020/8/7.
//  Copyright © 2020 denglongmin. All rights reserved.
//

#import "YFAdsSplashManager.h"
#import <UIKit/UIKit.h>
#import "YFAdsConstant.h"
#import "YFAdsUtils.h"
#import <YFAdsSDK/YFAdSplash.h>

@interface YFAdsSplashManager()<YFAdSplashDelegate>

@property (nonatomic, strong) YFAdSplash *splashAd;
@property (nonatomic, copy) NSString *posId;
@property (nonatomic) NSTimeInterval lastRequestTime;
@property (nonatomic, strong) FlutterEventSink flutterEventSink;

@end

@implementation YFAdsSplashManager

- (instancetype)initWithPostId:(NSString *)posId eventSink:(FlutterEventSink)eventSink {
    self = [super init];
    self.posId = posId;
    self.flutterEventSink = eventSink;
    return self;
}

//设置进入后台的时间戳
- (void)setAppBackTimeStamp {
    self.lastRequestTime = [NSDate date].timeIntervalSince1970;
}

- (void)hotLoadAdAndShow {
    if (([NSDate date].timeIntervalSince1970 - self.lastRequestTime) < 10) {
        NSLog(@"冷却时间小于10秒钟");
        return;
    }
    [self loadSplash];

}

- (void)loadAdAndShow {
    [self loadSplash];
}

- (UIView *)buildBgView {
    UIView *bgView = [[UIView alloc] initWithFrame:[UIScreen mainScreen].bounds];
    bgView.backgroundColor = [UIColor whiteColor];

    NSString *path = [[NSBundle mainBundle] pathForResource:@"default_splash_back" ofType:@"png"];
    BOOL fileExists = [[NSFileManager defaultManager] fileExistsAtPath:path];
    if(fileExists){
        UIImage *imgBg = [UIImage imageNamed:@"default_splash_back.png"];
        CGFloat imgHeight = imgBg.size.height/imgBg.size.width*kScreenWidth;
        UIImageView* bgImgView = [[UIImageView alloc] initWithFrame:CGRectMake(0, kScreenHeight-imgHeight, kScreenWidth, imgHeight)];
        bgImgView.image = imgBg;
        [bgView addSubview:bgImgView];
    }
    return bgView;
}

 
- (YFAdSplash *)returnAdInstance {
    YFAdSplash *splash = [[YFAdSplash alloc] initWithAdUnitID:self.posId viewController:nil];
    splash.delegate = self;
    splash.showLogoRequire = YES;
    splash.logoImage = [UIImage imageNamed:@"app_logo"];
    splash.backgroundImage = [UIImage imageNamed:@"LaunchImage_img"];
    splash.timeout = 5;
    return splash;
}


#pragma mark YFAdSplashDelegate


- (void)loadSplash{

    self.splashAd = [self returnAdInstance];
    [self.splashAd loadAndShowAd];
    
}

- (void)dealloc {
    self.splashAd = nil;
    self.splashAd.delegate = nil;
}

/// 广告数据加载成功
- (void)fcAdLoadSuccess:(YFAdBaseAdapter *)model {
    NSLog(@"广告数据加载成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidLoad" forKey:KEY_METHOD];
    [self callBack:result];

}
/// 广告曝光成功
- (void)fcAdExposured:(YFAdBaseAdapter *)model  {
    NSLog(@"广告曝光成功 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdExpose" forKey:KEY_METHOD];
    [self callBack:result];
}

/// 广告加载失败
- (void)fcAdFailedWithError:(NSError *)error description:(NSDictionary *)description{
    NSLog(@"广告数据加载失败 %s %@", __func__,description);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdLoadFail" forKey:KEY_METHOD];
    [result setValue:error.localizedDescription forKey:KEY_ERROR];
    [self callBack:result];
    
}

/// 广告点击
- (void)fcAdClicked:(YFAdBaseAdapter *)model  {
    NSLog(@"广告点击 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidClick" forKey:KEY_METHOD];
    [self callBack:result];
    
}

/// 广告关闭
- (void)fcAdDidClose:(YFAdBaseAdapter *)model  {
    NSLog(@"广告关闭了 %s", __func__);
    NSMutableDictionary *result = [NSMutableDictionary new];
    [result setValue:@"yfSplashAdDidClose" forKey:KEY_METHOD];
    [self callBack:result];

}

//- (void)fcAdDidCloseWithView:(UIView *)model  {
//    NSLog(@"广告关闭了 %s", __func__);
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"yfSplashAdDidClose" forKey:KEY_METHOD];
//    [self callBack:result];
//
//}


/// 广告倒计时结束
- (void)fcAdSplashOnAdCountdownToZero {
    NSLog(@"广告倒计时结束 %s", __func__);
}

/// 点击了跳过
- (void)fcAdSplashOnAdSkipClicked {
    NSLog(@"点击了跳过 %s", __func__);
}

/// 广告关闭Controller 的回调
- (void)fcAdDidCloseOtherController:(YFAdBaseAdapter *)model
                    interactionType:(YFAdInteractionType)interactionType {
    
        NSLog(@"广告关闭Controller的回调");
        NSMutableDictionary *result = [NSMutableDictionary new];
        [result setValue:@"fcAdDidCloseOtherController" forKey:KEY_METHOD];
        [self callBack:result];
    
}

///  开屏广告即将关闭
//- (void)WHSplashAdCustomWillClosed:(WHSplashAd *)splashAd {
//    NSLog(@"WH开屏自定义广告即将关闭");
//    NSMutableDictionary *result = [NSMutableDictionary new];
//    [result setValue:@"WHSplashAdCustomWillClosed" forKey:KEY_METHOD];
//    [self callBack:result];
//}


-(void)callBack:(NSMutableDictionary *)resultDic{
    [resultDic setValue:AD_TYPE_SPLASH forKey:KEY_AD_TYPE];
    NSString * result = [YFAdsUtils dictionary2JsonString:resultDic];
    _flutterEventSink(result);
}


@end
